@@ -321,7 +321,7 @@ STATS[["mean.diffs.target"]] <- {list(
     disp_stat = "disp.diff",
     adj_only = TRUE,
     abs = function(x) abs_(x),
-    bal.tab_column_prefix = "Diff", #Also which.stat in love.plot
+    bal.tab_column_prefix = "Diff.Target", #Also which.stat in love.plot
     threshold_range = c(0, Inf),
     balance_tally_for = "target mean differences",
     variable_with_the_greatest = "target mean difference", #also which.stat2 in love.plot
@@ -429,7 +429,7 @@ STATS[["ks.statistics.target"]] <- {list(
     disp_stat = "disp.ks",
     adj_only = TRUE,
     abs = function(x) abs_(x),
-    bal.tab_column_prefix = "KS", #Also which.stat in love.plot
+    bal.tab_column_prefix = "KS.Target", #Also which.stat in love.plot
     threshold_range = c(0, 1),
     balance_tally_for = "target KS statistics",
     variable_with_the_greatest = "target KS statistic", #also which.stat2 in love.plot
