@@ -69,6 +69,37 @@ base.bal.tab.cluster <- function(X,
     
     X$covs <- do.call(".get_C2", c(X, A[names(A) %nin% names(X)]), quote = TRUE)
     
+    var_types <- attr(X$covs, "var_types")
+    
+    if (get.treat.type(X$treat) != "continuous") {
+        if (is_null(A$continuous)) A$continuous <- getOption("cobalt_continuous", "std")
+        if (is_null(A$binary)) A$binary <- getOption("cobalt_binary", "raw")
+    }
+    else {
+        if (is_null(A$continuous)) A$continuous <- getOption("cobalt_continuous", "std")
+        if (is_null(A$binary)) A$binary <- getOption("cobalt_binary", "std")
+    }
+    
+    if (get.treat.type(X$treat) != "continuous" &&
+        "mean.diffs" %in% X$stats &&
+        ((A$binary == "std" && any(var_types == "Binary")) ||
+         (A$continuous == "std" && any(var_types != "Binary")))) {
+        X$s.d.denom <- .get_s.d.denom(X$s.d.denom,
+                                      estimand = X$estimand,
+                                      weights = X$weights, 
+                                      subclass = X$subclass,
+                                      treat = X$treat,
+                                      focal = X$focal)
+    }
+    else if (get.treat.type(X$treat) == "continuous" &&
+             any(c("correlations", "spearman.correlations") %in% X$stats) &&
+             ((A$binary == "std" && any(var_types == "Binary")) ||
+              (A$continuous == "std" && any(var_types != "Binary")))) {
+        X$s.d.denom <- .get_s.d.denom.cont(X$s.d.denom,
+                                           weights = X$weights,
+                                           subclass = X$subclass)
+    }
+    
     #Setup output object
     out <- list()
     
@@ -78,7 +109,7 @@ base.bal.tab.cluster <- function(X,
         X_cl$call <- NULL
         
         tryCatch({
-            do.call("base.bal.tab", c(list(X_cl), A[names(A) %nin% names(X_cl)]), quote = TRUE)
+            do.call("base.bal.tab", c(list(X_cl), A[setdiff(names(A), names(X_cl))]), quote = TRUE)
         },
         error = function(e) {
             .err(sprintf("in cluster %s: %s", add_quotes(cl), conditionMessage(e)))
