@@ -1,6 +1,6 @@
 .onAttach <- function(libname, pkgname) {
-    version <- packageVersion(pkgname)
-    BuildDate <- packageDate(pkgname)
+    version <- utils::packageVersion(pkgname)
+    BuildDate <- utils::packageDate(pkgname)
     
     foo <- paste0(" ", pkgname, " (Version ", version, ", Build Date: ", if (!anyNA(BuildDate)) format(BuildDate, "%F"), ")")
     packageStartupMessage(foo)
